azure.eventhub package
======================

    .. autoclass:: azure.eventhub.EventHubConsumerClient
        :members:
        :undoc-members:
        :inherited-members:

    .. autoclass:: azure.eventhub.EventHubProducerClient
        :members:
        :undoc-members:
        :inherited-members:

    .. autoclass:: azure.eventhub.EventData
        :members:
        :undoc-members:
        :inherited-members:

    .. autoclass:: azure.eventhub.EventDataBatch
        :members:
        :undoc-members:
        :inherited-members:

    .. autoclass:: azure.eventhub.EventHubSharedKeyCredential
        :members:
        :undoc-members:
        :inherited-members:

    .. autoclass:: azure.eventhub.CheckpointStore
        :members:
        :undoc-members:
        :inherited-members:

    .. autoclass:: azure.eventhub.PartitionContext
        :members:
        :undoc-members:
        :inherited-members:

    .. autoclass:: azure.eventhub.CloseReason
        :members:
        :undoc-members:
        :inherited-members:

    .. autoclass:: azure.eventhub.TransportType
        :members:
        :undoc-members:
        :inherited-members:
    .. autoclass:: azure.eventhub.LoadBalancingStrategy
        :members:
        :undoc-members:
        :inherited-members:


Subpackages
-----------

.. toctree::

   azure.eventhub.aio
   azure.eventhub.exceptions
   azure.eventhub.amqp
